
# ----------------------------------------------------------------------
# | Copyright  Unpublished, Rational Software Corporation. All Rights |
# | Reserved.  This software contains proprietary and confidential     |
# | information of Rational and its suppliers.  Use, disclosure or     |
# | reproduction is prohibited without the prior express written       |
# | consent of Rational Software Corporation.                          |
# ----------------------------------------------------------------------

#
# FILE: ccpb_deliver.pbl
#
# PURPOSE: This is a deliver_start postop trigger which recreates
#          PowerBuilder Libraries (PBLs) which are modified as a
#          result of a UCM deliver.
#

#
# get a space separated list of all UCM activities being delivered
#
$dev_act = $ENV{'CLEARCASE_DLVR_ACTS'};

#
# setup for debug
#
$debug = $ENV{'CCPB_DELIVER_DEBUG'};
if ( $debug ) {
  $outfilename = "c:\\temp\\ccpb_deliver_debug.txt";
  open(OUT,">$outfilename") ||
      die "cannot create $outfilename: $!";
  print OUT "development_acts = $dev_act\n";
}

$pbl_count = 0;

# process each activity
foreach $act ( split ( " ", $dev_act ) ) {

  # skip rebase activities
  if ( not grep ( /rebase\./, $act ) ) {
    print OUT "process this activity: $act\n" if $debug;

    # get the PBL entries in the current activity's change set
    @pbls = grep ( /\.pbl@@/, `cleartool lsact -l $act` );

    # process each of the PBL entries
    foreach $pbl ( @pbls ) {
      # strip off the CC extended path
      ( $pbl_path ) = split ( "@@", $pbl );

      # strip off blanks
      $pbl_path =~ s/ //g;

      # determine if PBL path has already been added
      $pbl_path =~ s/\\/\//g;
      if ( not grep ( /$pbl_path/, @pbl_list ) ) {
        # add unique PBL path
        @pbl_list[$pbl_count++] = $pbl_path;
        print OUT "    added pbl: $pbl_path\n" if $debug;
      }
    }
  }
}

print OUT "\n\n\n" if $debug;

# process each PBL in our list
foreach $pbl ( @pbl_list ) {
  # construct path to POL element
  $pol_path = $pbl;
  $pol_path =~ s/.pbl/.pol/;
  $pol_path =~ s/\//\\/g;
  print OUT "    run pblpopulate on: $pol_path\n" if $debug;

  # execute the pblpopulate utility
  `pblpopulate.exe -silent $pol_path`;
}

close(OUT) if $debug;
